Module: Turbopuffer::Models::AttributeEmbed

Extended by:
Internal::Type::Union
Defined in:
lib/turbopuffer/models/attribute_embed.rb,
sig/turbopuffer/models/attribute_embed.rbs

Overview

Whether to automatically embed this string attribute into a vector attribute. Can be a model name, a detailed configuration object, or null to remove an existing embedding configuration.

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.variantsArray(String, Turbopuffer::Models::AttributeEmbedConfig)

Returns:



# File 'lib/turbopuffer/models/attribute_embed.rb', line 17

Instance Method Details

#self?.variants::Array[Turbopuffer::Models::attribute_embed]

Returns:

  • (::Array[Turbopuffer::Models::attribute_embed])


8
# File 'sig/turbopuffer/models/attribute_embed.rbs', line 8

def self?.variants: -> ::Array[Turbopuffer::Models::attribute_embed]