Module: Turbopuffer::Models::AttributeSchemaConfig::Ann

Extended by:
Internal::Type::Union
Defined in:
lib/turbopuffer/models/attribute_schema_config.rb,
sig/turbopuffer/models/attribute_schema_config.rbs

Overview

Whether to create an approximate nearest neighbor index for the attribute. Can be a boolean or a detailed configuration object.

See Also:

  • Turbopuffer::Models::AttributeSchemaConfig#ann

Defined Under Namespace

Classes: AnnConfig

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[Turbopuffer::Models::AttributeSchemaConfig::ann]

Returns:

  • (::Array[Turbopuffer::Models::AttributeSchemaConfig::ann])


112
# File 'sig/turbopuffer/models/attribute_schema_config.rbs', line 112

def self?.variants: -> ::Array[Turbopuffer::Models::AttributeSchemaConfig::ann]