Class: Turbopuffer::Models::CopyFromNamespaceParams::CopyFromNamespaceConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/turbopuffer/models/copy_from_namespace_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(source_namespace:, source_api_key: nil, source_region: nil) ⇒ Object

Parameters:

  • source_namespace (String)

    The namespace to copy documents from.

  • source_api_key (String) (defaults to: nil)

    (Optional) An API key for the organization containing the source namespace

  • source_region (String) (defaults to: nil)

    (Optional) The region of the source namespace.



# File 'lib/turbopuffer/models/copy_from_namespace_params.rb', line 33

Instance Attribute Details

#source_api_keyString?

(Optional) An API key for the organization containing the source namespace

Returns:

  • (String, nil)


25
# File 'lib/turbopuffer/models/copy_from_namespace_params.rb', line 25

optional :source_api_key, String

#source_namespaceString

The namespace to copy documents from.

Returns:

  • (String)


19
# File 'lib/turbopuffer/models/copy_from_namespace_params.rb', line 19

required :source_namespace, String

#source_regionString?

(Optional) The region of the source namespace.

Returns:

  • (String, nil)


31
# File 'lib/turbopuffer/models/copy_from_namespace_params.rb', line 31

optional :source_region, String