Class: Turbopuffer::Models::FuzzyMaxEditDistance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/turbopuffer/models/fuzzy_max_edit_distance.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(distance:, min_query_chars:) ⇒ Object

Some parameter documentations has been truncated, see Turbopuffer::Models::FuzzyMaxEditDistance for more details.

An edit distance threshold for the Fuzzy filter.

Parameters:

  • distance (Integer)

    The maximum edit distance to allow.

  • min_query_chars (Integer)

    Minimum number of characters in a query where this distance applies. Must be at



# File 'lib/turbopuffer/models/fuzzy_max_edit_distance.rb', line 19

Instance Attribute Details

#distanceInteger

The maximum edit distance to allow.

Returns:

  • (Integer)


10
# File 'lib/turbopuffer/models/fuzzy_max_edit_distance.rb', line 10

required :distance, Integer

#min_query_charsInteger

Minimum number of characters in a query where this distance applies. Must be at least 3 ยท (distance + 1).

Returns:

  • (Integer)


17
# File 'lib/turbopuffer/models/fuzzy_max_edit_distance.rb', line 17

required :min_query_chars, Integer