Class: Turbopuffer::Models::NamespaceCopyFromResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/turbopuffer/models/namespace_copy_from_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(billing:, message:, rows_affected:, deleted_ids: nil, patched_ids: nil, performance: nil, rows_deleted: nil, rows_patched: nil, rows_remaining: nil, rows_upserted: nil, upserted_ids: nil, status: :OK) ⇒ Object

Some parameter documentations has been truncated, see Turbopuffer::Models::NamespaceCopyFromResponse for more details.

The response to a successful write request.

Parameters:

  • billing (Turbopuffer::Models::WriteBilling)

    The billing information for a write request.

  • message (String)

    A message describing the result of the write request.

  • rows_affected (Integer)

    The number of rows affected by the write request.

  • deleted_ids (Array<String, Integer>) (defaults to: nil)

    The IDs of documents that were deleted. Only included when ‘return_affected_ids`

  • patched_ids (Array<String, Integer>) (defaults to: nil)

    The IDs of documents that were patched. Only included when ‘return_affected_ids`

  • performance (Turbopuffer::Models::WritePerformance) (defaults to: nil)

    The performance information for a write request.

  • rows_deleted (Integer) (defaults to: nil)

    The number of rows deleted by the write request.

  • rows_patched (Integer) (defaults to: nil)

    The number of rows patched by the write request.

  • rows_remaining (Boolean) (defaults to: nil)

    Whether more documents match the filter for partial operations.

  • rows_upserted (Integer) (defaults to: nil)

    The number of rows upserted by the write request.

  • upserted_ids (Array<String, Integer>) (defaults to: nil)

    The IDs of documents that were upserted. Only included when ‘return_affected_ids

  • status (Symbol, :OK) (defaults to: :OK)

    The status of the request.



# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 82

Instance Attribute Details

#billingTurbopuffer::Models::WriteBilling

The billing information for a write request.



11
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 11

required :billing, -> { Turbopuffer::WriteBilling }

#deleted_idsArray<String, Integer>?

The IDs of documents that were deleted. Only included when ‘return_affected_ids` is true and at least one document was deleted.

Returns:

  • (Array<String, Integer>, nil)


36
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 36

optional :deleted_ids, -> { Turbopuffer::Internal::Type::ArrayOf[union: Turbopuffer::ID] }

#messageString

A message describing the result of the write request.

Returns:

  • (String)


17
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 17

required :message, String

#patched_idsArray<String, Integer>?

The IDs of documents that were patched. Only included when ‘return_affected_ids` is true and at least one document was patched.

Returns:

  • (Array<String, Integer>, nil)


43
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 43

optional :patched_ids, -> { Turbopuffer::Internal::Type::ArrayOf[union: Turbopuffer::ID] }

#performanceTurbopuffer::Models::WritePerformance?

The performance information for a write request.



49
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 49

optional :performance, -> { Turbopuffer::WritePerformance }

#rows_affectedInteger

The number of rows affected by the write request.

Returns:

  • (Integer)


23
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 23

required :rows_affected, Integer

#rows_deletedInteger?

The number of rows deleted by the write request.

Returns:

  • (Integer, nil)


55
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 55

optional :rows_deleted, Integer

#rows_patchedInteger?

The number of rows patched by the write request.

Returns:

  • (Integer, nil)


61
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 61

optional :rows_patched, Integer

#rows_remainingBoolean?

Whether more documents match the filter for partial operations.

Returns:

  • (Boolean, nil)


67
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 67

optional :rows_remaining, Turbopuffer::Internal::Type::Boolean

#rows_upsertedInteger?

The number of rows upserted by the write request.

Returns:

  • (Integer, nil)


73
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 73

optional :rows_upserted, Integer

#statusSymbol, :OK

The status of the request.

Returns:

  • (Symbol, :OK)


29
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 29

required :status, const: :OK

#upserted_idsArray<String, Integer>?

The IDs of documents that were upserted. Only included when ‘return_affected_ids` is true and at least one document was upserted.

Returns:

  • (Array<String, Integer>, nil)


80
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 80

optional :upserted_ids, -> { Turbopuffer::Internal::Type::ArrayOf[union: Turbopuffer::ID] }