Class: Turbopuffer::Models::NamespaceMetadata::Index::IndexUpdating
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::NamespaceMetadata::Index::IndexUpdating
- Defined in:
- lib/turbopuffer/models/namespace_metadata.rb,
sig/turbopuffer/models/namespace_metadata.rbs
Instance Attribute Summary collapse
- #status ⇒ Symbol, :updating
-
#unindexed_bytes ⇒ Integer
The number of bytes in the namespace that are in the write-ahead log but have not yet been indexed.
Instance Method Summary collapse
-
#initialize ⇒ IndexUpdating
constructor
A new instance of IndexUpdating.
- #to_hash ⇒ { status: :updating, unindexed_bytes: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ IndexUpdating
Returns a new instance of IndexUpdating.
91 |
# File 'sig/turbopuffer/models/namespace_metadata.rbs', line 91
def initialize: (unindexed_bytes: Integer, ?status: :updating) -> void
|
Instance Attribute Details
#status ⇒ Symbol, :updating
110 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 110 required :status, const: :updating |
#unindexed_bytes ⇒ Integer
The number of bytes in the namespace that are in the write-ahead log but have not yet been indexed.
117 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 117 required :unindexed_bytes, Integer |
Instance Method Details
#to_hash ⇒ { status: :updating, unindexed_bytes: Integer }
93 |
# File 'sig/turbopuffer/models/namespace_metadata.rbs', line 93
def to_hash: -> { status: :updating, unindexed_bytes: Integer }
|