Class: Turbopuffer::Models::NamespaceMetadata::Pinning::Status

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/turbopuffer/models/namespace_metadata.rb,
sig/turbopuffer/models/namespace_metadata.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ready_replicas:, replicas:, updated_at:, utilization:) ⇒ Object

Some parameter documentations has been truncated, see Turbopuffer::Models::NamespaceMetadata::Pinning::Status for more details.

Operational status for a pinned namespace.

Parameters:

  • ready_replicas (Integer)

    The number of replicas that are warm and serving traffic.

  • replicas (Integer)

    The number of running replicas for the namespace. Replicas are billed once runni

  • updated_at (Time)

    The timestamp of the latest pinning status snapshot.

  • utilization (Float)

    Aggregate utilization for the pinned namespace, reported as a value between 0.0



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 154

class Status < Turbopuffer::Internal::Type::BaseModel
  # @!attribute ready_replicas
  #   The number of replicas that are warm and serving traffic.
  #
  #   @return [Integer]
  required :ready_replicas, Integer

  # @!attribute replicas
  #   The number of running replicas for the namespace. Replicas are billed once
  #   running, even before they finish warming their caches and become ready to serve
  #   traffic. This count is updated independently and may briefly disagree with the
  #   other status fields.
  #
  #   @return [Integer]
  required :replicas, Integer

  # @!attribute updated_at
  #   The timestamp of the latest pinning status snapshot.
  #
  #   @return [Time]
  required :updated_at, Time

  # @!attribute utilization
  #   Aggregate utilization for the pinned namespace, reported as a value between 0.0
  #   and 1.0.
  #
  #   @return [Float]
  required :utilization, Float

  # @!method initialize(ready_replicas:, replicas:, updated_at:, utilization:)
  #   Some parameter documentations has been truncated, see
  #   {Turbopuffer::Models::NamespaceMetadata::Pinning::Status} for more details.
  #
  #   Operational status for a pinned namespace.
  #
  #   @param ready_replicas [Integer] The number of replicas that are warm and serving traffic.
  #
  #   @param replicas [Integer] The number of running replicas for the namespace. Replicas are billed once runni
  #
  #   @param updated_at [Time] The timestamp of the latest pinning status snapshot.
  #
  #   @param utilization [Float] Aggregate utilization for the pinned namespace, reported as a value between 0.0
end

Instance Attribute Details

#ready_replicasInteger

The number of replicas that are warm and serving traffic.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


159
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 159

required :ready_replicas, Integer

#replicasInteger

The number of running replicas for the namespace. Replicas are billed once running, even before they finish warming their caches and become ready to serve traffic. This count is updated independently and may briefly disagree with the other status fields.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


168
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 168

required :replicas, Integer

#updated_atTime

The timestamp of the latest pinning status snapshot.

Parameters:

  • value (Time)

Returns:

  • (Time)


174
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 174

required :updated_at, Time

#utilizationFloat

Aggregate utilization for the pinned namespace, reported as a value between 0.0 and 1.0.

Parameters:

  • value (Float)

Returns:

  • (Float)


181
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 181

required :utilization, Float

Instance Method Details

#to_hash{

Returns:

  • ({)


147
# File 'sig/turbopuffer/models/namespace_metadata.rbs', line 147

def to_hash: -> {