Class: Turbopuffer::Models::NamespaceMultiQueryParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::NamespaceMultiQueryParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/turbopuffer/models/namespace_multi_query_params.rb,
sig/turbopuffer/models/namespace_multi_query_params.rbs
Overview
Defined Under Namespace
Classes: Consistency, Query
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::Turbopuffer
Instance Attribute Summary collapse
-
#consistency ⇒ Turbopuffer::Models::NamespaceMultiQueryParams::Consistency?
The consistency level for a query.
- #namespace ⇒ String?
- #queries ⇒ Array<Turbopuffer::Models::NamespaceMultiQueryParams::Query>
-
#rerank_by ⇒ Object?
How to combine the rows returned by each sub-query into a single ranked list.
-
#vector_encoding ⇒ Symbol, ...
The encoding to use for vectors in the response.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
39 |
# File 'sig/turbopuffer/models/namespace_multi_query_params.rbs', line 39
def initialize: (
|
Instance Attribute Details
#consistency ⇒ Turbopuffer::Models::NamespaceMultiQueryParams::Consistency?
The consistency level for a query.
25 |
# File 'lib/turbopuffer/models/namespace_multi_query_params.rb', line 25 optional :consistency, -> { Turbopuffer::NamespaceMultiQueryParams::Consistency } |
#namespace ⇒ String?
13 |
# File 'lib/turbopuffer/models/namespace_multi_query_params.rb', line 13 optional :namespace, String |
#queries ⇒ Array<Turbopuffer::Models::NamespaceMultiQueryParams::Query>
18 19 |
# File 'lib/turbopuffer/models/namespace_multi_query_params.rb', line 18 required :queries, -> { Turbopuffer::Internal::Type::ArrayOf[Turbopuffer::NamespaceMultiQueryParams::Query] } |
#rerank_by ⇒ Object?
How to combine the rows returned by each sub-query into a single ranked list.
31 |
# File 'lib/turbopuffer/models/namespace_multi_query_params.rb', line 31 optional :rerank_by, Turbopuffer::Internal::Type::Unknown |
#vector_encoding ⇒ Symbol, ...
The encoding to use for vectors in the response.
37 |
# File 'lib/turbopuffer/models/namespace_multi_query_params.rb', line 37 optional :vector_encoding, enum: -> { Turbopuffer::VectorEncoding } |
Class Method Details
.variants ⇒ Array(Integer, Turbopuffer::Models::Limit)
|
|
# File 'lib/turbopuffer/models/namespace_multi_query_params.rb', line 156
|
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/turbopuffer/models/namespace_multi_query_params.rbs', line 48
def to_hash: -> {
|