Class: Turbopuffer::Models::NamespaceRecallResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/turbopuffer/models/namespace_recall_response.rb,
sig/turbopuffer/models/namespace_recall_response.rbs

Overview

See Also:

  • Turbopuffer::Resources::Namespaces#recall

Defined Under Namespace

Classes: GroundTruth

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



24
# File 'sig/turbopuffer/models/namespace_recall_response.rbs', line 24

def initialize: (

Instance Attribute Details

#avg_ann_countFloat

The average number of documents retrieved by the approximate nearest neighbor searches.

Parameters:

  • value (Float)

Returns:

  • (Float)


12
# File 'lib/turbopuffer/models/namespace_recall_response.rb', line 12

required :avg_ann_count, Float

#avg_exhaustive_countFloat

The average number of documents retrieved by the exhaustive searches.

Parameters:

  • value (Float)

Returns:

  • (Float)


18
# File 'lib/turbopuffer/models/namespace_recall_response.rb', line 18

required :avg_exhaustive_count, Float

#avg_recallFloat

The average recall of the queries.

Parameters:

  • value (Float)

Returns:

  • (Float)


24
# File 'lib/turbopuffer/models/namespace_recall_response.rb', line 24

required :avg_recall, Float

#ground_truthArray<Turbopuffer::Models::NamespaceRecallResponse::GroundTruth>?

Ground truth data including query vectors and true nearest neighbors. Only included when include_ground_truth is true.



31
32
# File 'lib/turbopuffer/models/namespace_recall_response.rb', line 31

optional :ground_truth,
-> { Turbopuffer::Internal::Type::ArrayOf[Turbopuffer::Models::NamespaceRecallResponse::GroundTruth] }

Instance Method Details

#to_hash{

Returns:

  • ({)


31
# File 'sig/turbopuffer/models/namespace_recall_response.rbs', line 31

def to_hash: -> {