Class: Turbopuffer::Models::NamespaceWriteParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/turbopuffer/models/namespace_write_params.rb

Overview

Defined Under Namespace

Classes: PatchByFilter

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Turbopuffer::Internal::Type::BaseModel

Instance Attribute Details

#branch_from_namespaceString, ...

The namespace to create an instant, copy-on-write clone of.



19
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 19

optional :branch_from_namespace, union: -> { Turbopuffer::BranchFromNamespaceParams }

#copy_from_namespaceString, ...

The namespace to copy documents from.



25
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 25

optional :copy_from_namespace, union: -> { Turbopuffer::CopyFromNamespaceParams }

#delete_by_filterObject?

The filter specifying which documents to delete.

Returns:

  • (Object, nil)


31
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 31

optional :delete_by_filter, Turbopuffer::Internal::Type::Unknown

#delete_by_filter_allow_partialBoolean?

Allow partial completion when filter matches too many documents.

Returns:

  • (Boolean, nil)


37
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 37

optional :delete_by_filter_allow_partial, Turbopuffer::Internal::Type::Boolean

#delete_conditionObject?

A condition evaluated against the current value of each document targeted by a delete write. Only documents that pass the condition are deleted.

Returns:

  • (Object, nil)


44
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 44

optional :delete_condition, Turbopuffer::Internal::Type::Unknown

#deletesArray<String, Integer>?

Returns:

  • (Array<String, Integer>, nil)


49
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 49

optional :deletes, -> { Turbopuffer::Internal::Type::ArrayOf[union: Turbopuffer::ID] }

#disable_backpressureBoolean?

Disables write throttling (HTTP 429 responses) during high-volume ingestion.

Returns:

  • (Boolean, nil)


55
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 55

optional :disable_backpressure, Turbopuffer::Internal::Type::Boolean

#distance_metricSymbol, ...

A function used to calculate vector similarity.

Returns:



61
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 61

optional :distance_metric, enum: -> { Turbopuffer::DistanceMetric }

#encryptionTurbopuffer::Models::Encryption::CustomerManaged, ...

The encryption configuration for a namespace.



67
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 67

optional :encryption, union: -> { Turbopuffer::Encryption }

#namespaceString?

Returns:

  • (String, nil)


13
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 13

optional :namespace, String

#patch_by_filterTurbopuffer::Models::NamespaceWriteParams::PatchByFilter?

The patch and filter specifying which documents to patch.



73
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 73

optional :patch_by_filter, -> { Turbopuffer::NamespaceWriteParams::PatchByFilter }

#patch_by_filter_allow_partialBoolean?

Allow partial completion when filter matches too many documents.

Returns:

  • (Boolean, nil)


79
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 79

optional :patch_by_filter_allow_partial, Turbopuffer::Internal::Type::Boolean

#patch_columnsTurbopuffer::Models::Columns?

A list of documents in columnar format. Each key is a column name, mapped to an array of values for that column.



86
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 86

optional :patch_columns, -> { Turbopuffer::Columns }

#patch_conditionObject?

A condition evaluated against the current value of each document targeted by a patch write. Only documents that pass the condition are patched.

Returns:

  • (Object, nil)


93
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 93

optional :patch_condition, Turbopuffer::Internal::Type::Unknown

#patch_rowsArray<Turbopuffer::Models::Row>?

Returns:



98
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 98

optional :patch_rows, -> { Turbopuffer::Internal::Type::ArrayOf[Turbopuffer::Row] }

#return_affected_idsBoolean?

If true, return the IDs of affected rows (deleted, patched, upserted) in the response. For filtered and conditional writes, only IDs for writes that succeeded will be included.

Returns:

  • (Boolean, nil)


106
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 106

optional :return_affected_ids, Turbopuffer::Internal::Type::Boolean

#schemaHash{Symbol=>String, Turbopuffer::Models::AttributeSchemaConfig}?

The schema of the attributes attached to the documents.

Returns:



112
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 112

optional :schema, -> { Turbopuffer::Internal::Type::HashOf[union: Turbopuffer::AttributeSchema] }

#upsert_columnsTurbopuffer::Models::Columns?

A list of documents in columnar format. Each key is a column name, mapped to an array of values for that column.



119
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 119

optional :upsert_columns, -> { Turbopuffer::Columns }

#upsert_conditionObject?

A condition evaluated against the current value of each document targeted by an upsert write. Only documents that pass the condition are upserted.

Returns:

  • (Object, nil)


126
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 126

optional :upsert_condition, Turbopuffer::Internal::Type::Unknown

#upsert_rowsArray<Turbopuffer::Models::Row>?

Returns:



131
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 131

optional :upsert_rows, -> { Turbopuffer::Internal::Type::ArrayOf[Turbopuffer::Row] }