Class: Turbopuffer::Models::NamespaceWriteParams::PatchByFilter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/turbopuffer/models/namespace_write_params.rb,
sig/turbopuffer/models/namespace_write_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filters:, patch:) ⇒ PatchByFilter

The patch and filter specifying which documents to patch.

Parameters:

  • filters (Object)

    Filter by attributes. Same syntax as the query endpoint.

  • patch (Hash{Symbol=>Object})
  • filters: (top)
  • patch: (::Hash[Symbol, top])


190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 190

class PatchByFilter < Turbopuffer::Internal::Type::BaseModel
  # @!attribute filters
  #   Filter by attributes. Same syntax as the query endpoint.
  #
  #   @return [Object]
  required :filters, Turbopuffer::Internal::Type::Unknown

  # @!attribute patch
  #
  #   @return [Hash{Symbol=>Object}]
  required :patch, Turbopuffer::Internal::Type::HashOf[Turbopuffer::Internal::Type::Unknown]

  # @!method initialize(filters:, patch:)
  #   The patch and filter specifying which documents to patch.
  #
  #   @param filters [Object] Filter by attributes. Same syntax as the query endpoint.
  #
  #   @param patch [Hash{Symbol=>Object}]
end

Instance Attribute Details

#filtersObject

Filter by attributes. Same syntax as the query endpoint.

Parameters:

  • value (top)

Returns:

  • (Object)


195
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 195

required :filters, Turbopuffer::Internal::Type::Unknown

#patchHash{Symbol=>Object}

Parameters:

  • value (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object})


200
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 200

required :patch, Turbopuffer::Internal::Type::HashOf[Turbopuffer::Internal::Type::Unknown]

Instance Method Details

#to_hash{ filters: top, patch: ::Hash[Symbol, top] }

Returns:

  • ({ filters: top, patch: ::Hash[Symbol, top] })


192
# File 'sig/turbopuffer/models/namespace_write_params.rbs', line 192

def to_hash: -> { filters: top, patch: ::Hash[Symbol, top] }