Class: Turbopuffer::Models::RerankLimit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::RerankLimit
- Defined in:
- lib/turbopuffer/models/rerank_limit.rb,
sig/turbopuffer/models/rerank_limit.rbs
Instance Attribute Summary collapse
-
#total ⇒ Integer
Limits the total number of documents returned after reranking.
Instance Method Summary collapse
-
#initialize(total:) ⇒ RerankLimit
constructor
Limits the total number of reranked documents returned.
- #to_hash ⇒ { total: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(total:) ⇒ RerankLimit
Limits the total number of reranked documents returned.
|
|
# File 'lib/turbopuffer/models/rerank_limit.rb', line 12
|
Instance Attribute Details
#total ⇒ Integer
Limits the total number of documents returned after reranking.
10 |
# File 'lib/turbopuffer/models/rerank_limit.rb', line 10 required :total, Integer |
Instance Method Details
#to_hash ⇒ { total: Integer }
10 |
# File 'sig/turbopuffer/models/rerank_limit.rbs', line 10
def to_hash: -> { total: Integer }
|