Class: Turbopuffer::Models::RrfParams

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/turbopuffer/models/rrf_params.rb,
sig/turbopuffer/models/rrf_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(rank_constant: nil, weights: nil) ⇒ Object

Some parameter documentations has been truncated, see Turbopuffer::Models::RrfParams for more details.

Configuration options for RRF.

Parameters:

  • rank_constant (Integer) (defaults to: nil)

    RRF rank constant (k). Must be greater than zero. Defaults to 60.

  • weights (Array<Float>) (defaults to: nil)

    A positive weight for each subquery, in the same order as queries. The number



# File 'lib/turbopuffer/models/rrf_params.rb', line 20

Instance Attribute Details

#rank_constantInteger?

RRF rank constant (k). Must be greater than zero. Defaults to 60.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


10
# File 'lib/turbopuffer/models/rrf_params.rb', line 10

optional :rank_constant, Integer

#weightsArray<Float>?

A positive weight for each subquery, in the same order as queries. The number of weights must match the number of subqueries. When omitted, every subquery has a weight of 1.

Parameters:

  • (::Array[Float])

Returns:

  • (Array<Float>, nil)


18
# File 'lib/turbopuffer/models/rrf_params.rb', line 18

optional :weights, Turbopuffer::Internal::Type::ArrayOf[Float]

Instance Method Details

#to_hash{ rank_constant: Integer, weights: ::Array[Float] }

Returns:

  • ({ rank_constant: Integer, weights: ::Array[Float] })


19
# File 'sig/turbopuffer/models/rrf_params.rbs', line 19

def to_hash: -> { rank_constant: Integer, weights: ::Array[Float] }