Class: Turbopuffer::Models::SaturateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::SaturateParams
- Defined in:
- lib/turbopuffer/models/saturate_params.rb
Instance Attribute Summary collapse
-
#exponent ⇒ Float?
An exponent that helps further control the shape of the Saturate function.
-
#midpoint ⇒ Object?
The midpoint of the Saturate operator.
Instance Method Summary collapse
-
#initialize(exponent: nil, midpoint: nil) ⇒ Object
constructor
Additional parameters for the Saturate operator.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(exponent: nil, midpoint: nil) ⇒ Object
Additional parameters for the Saturate operator.
|
|
# File 'lib/turbopuffer/models/saturate_params.rb', line 18
|
Instance Attribute Details
#exponent ⇒ Float?
An exponent that helps further control the shape of the Saturate function.
10 |
# File 'lib/turbopuffer/models/saturate_params.rb', line 10 optional :exponent, Float |
#midpoint ⇒ Object?
The midpoint of the Saturate operator.
16 |
# File 'lib/turbopuffer/models/saturate_params.rb', line 16 optional :midpoint, Turbopuffer::Internal::Type::Unknown |