Class: Turbopuffer::Models::ShardingConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::ShardingConfig
- Defined in:
- lib/turbopuffer/models/sharding_config.rb,
sig/turbopuffer/models/sharding_config.rbs
Instance Attribute Summary collapse
-
#num_shards ⇒ Integer
The number of shards to partition the namespace into.
Instance Method Summary collapse
-
#initialize(num_shards:) ⇒ ShardingConfig
constructor
Configuration for namespace sharding, which partitions a namespace's documents across multiple internal shards to scale indexing and query throughput beyond a single machine.
- #to_hash ⇒ { num_shards: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(num_shards:) ⇒ ShardingConfig
Configuration for namespace sharding, which partitions a namespace's documents across multiple internal shards to scale indexing and query throughput beyond a single machine. Sharding can only be configured on a namespace's inaugural write, and cannot be added to or changed on an existing namespace.
|
|
# File 'lib/turbopuffer/models/sharding_config.rb', line 12
|
Instance Attribute Details
#num_shards ⇒ Integer
The number of shards to partition the namespace into.
10 |
# File 'lib/turbopuffer/models/sharding_config.rb', line 10 required :num_shards, Integer |
Instance Method Details
#to_hash ⇒ { num_shards: Integer }
10 |
# File 'sig/turbopuffer/models/sharding_config.rbs', line 10
def to_hash: -> { num_shards: Integer }
|