Class: Turbopuffer::Models::Limit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::Limit
- Defined in:
- lib/turbopuffer/models/limit.rb
Defined Under Namespace
Classes: Per
Instance Attribute Summary collapse
-
#per ⇒ Turbopuffer::Models::Limit::Per?
Limits the number of documents with the same value for a set of attributes (the “limit key”) that can appear in the results.
-
#total ⇒ Integer
Limits the total number of documents returned.
Instance Method Summary collapse
-
#initialize(total:, per: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Limit for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(total:, per: nil) ⇒ Object
Some parameter documentations has been truncated, see Turbopuffer::Models::Limit for more details.
Limits the documents returned by a query.
|
|
# File 'lib/turbopuffer/models/limit.rb', line 19
|
Instance Attribute Details
#per ⇒ Turbopuffer::Models::Limit::Per?
Limits the number of documents with the same value for a set of attributes (the “limit key”) that can appear in the results.
17 |
# File 'lib/turbopuffer/models/limit.rb', line 17 optional :per, -> { Turbopuffer::Limit::Per } |
#total ⇒ Integer
Limits the total number of documents returned.
10 |
# File 'lib/turbopuffer/models/limit.rb', line 10 required :total, Integer |