Class: Turbopuffer::Models::Limit::Per
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::Limit::Per
- Defined in:
- lib/turbopuffer/models/limit.rb
Overview
Instance Attribute Summary collapse
-
#attributes ⇒ Array<String>
The attributes to include in the limit key.
-
#limit ⇒ Integer
The maximum number of documents to return for each value of the limit key.
Instance Method Summary collapse
-
#initialize(attributes:, limit:) ⇒ Object
constructor
Limits the number of documents with the same value for a set of attributes (the “limit key”) that can appear in the results.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attributes:, limit:) ⇒ Object
Limits the number of documents with the same value for a set of attributes (the “limit key”) that can appear in the results.
|
|
# File 'lib/turbopuffer/models/limit.rb', line 43
|
Instance Attribute Details
#attributes ⇒ Array<String>
The attributes to include in the limit key.
35 |
# File 'lib/turbopuffer/models/limit.rb', line 35 required :attributes, Turbopuffer::Internal::Type::ArrayOf[String] |
#limit ⇒ Integer
The maximum number of documents to return for each value of the limit key.
41 |
# File 'lib/turbopuffer/models/limit.rb', line 41 required :limit, Integer |