Class: Turbopuffer::Models::NamespaceCopyFromResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::NamespaceCopyFromResponse
- Defined in:
- lib/turbopuffer/models/namespace_copy_from_response.rb
Overview
Instance Attribute Summary collapse
-
#billing ⇒ Turbopuffer::Models::WriteBilling
The billing information for a write request.
-
#deleted_ids ⇒ Array<String, Integer>?
The IDs of documents that were deleted.
-
#message ⇒ String
A message describing the result of the write request.
-
#patched_ids ⇒ Array<String, Integer>?
The IDs of documents that were patched.
-
#performance ⇒ Turbopuffer::Models::WritePerformance?
The performance information for a write request.
-
#rows_affected ⇒ Integer
The number of rows affected by the write request.
-
#rows_deleted ⇒ Integer?
The number of rows deleted by the write request.
-
#rows_patched ⇒ Integer?
The number of rows patched by the write request.
-
#rows_remaining ⇒ Boolean?
Whether more documents match the filter for partial operations.
-
#rows_upserted ⇒ Integer?
The number of rows upserted by the write request.
-
#status ⇒ Symbol, :OK
The status of the request.
-
#upserted_ids ⇒ Array<String, Integer>?
The IDs of documents that were upserted.
Instance Method Summary collapse
-
#initialize(billing:, message:, rows_affected:, deleted_ids: nil, patched_ids: nil, performance: nil, rows_deleted: nil, rows_patched: nil, rows_remaining: nil, rows_upserted: nil, upserted_ids: nil, status: :OK) ⇒ Object
constructor
Some parameter documentations has been truncated, see NamespaceCopyFromResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing:, message:, rows_affected:, deleted_ids: nil, patched_ids: nil, performance: nil, rows_deleted: nil, rows_patched: nil, rows_remaining: nil, rows_upserted: nil, upserted_ids: nil, status: :OK) ⇒ Object
Some parameter documentations has been truncated, see Turbopuffer::Models::NamespaceCopyFromResponse for more details.
The response to a successful write request.
|
|
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 82
|
Instance Attribute Details
#billing ⇒ Turbopuffer::Models::WriteBilling
The billing information for a write request.
11 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 11 required :billing, -> { Turbopuffer::WriteBilling } |
#deleted_ids ⇒ Array<String, Integer>?
The IDs of documents that were deleted. Only included when ‘return_affected_ids` is true and at least one document was deleted.
36 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 36 optional :deleted_ids, -> { Turbopuffer::Internal::Type::ArrayOf[union: Turbopuffer::ID] } |
#message ⇒ String
A message describing the result of the write request.
17 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 17 required :message, String |
#patched_ids ⇒ Array<String, Integer>?
The IDs of documents that were patched. Only included when ‘return_affected_ids` is true and at least one document was patched.
43 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 43 optional :patched_ids, -> { Turbopuffer::Internal::Type::ArrayOf[union: Turbopuffer::ID] } |
#performance ⇒ Turbopuffer::Models::WritePerformance?
The performance information for a write request.
49 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 49 optional :performance, -> { Turbopuffer::WritePerformance } |
#rows_affected ⇒ Integer
The number of rows affected by the write request.
23 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 23 required :rows_affected, Integer |
#rows_deleted ⇒ Integer?
The number of rows deleted by the write request.
55 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 55 optional :rows_deleted, Integer |
#rows_patched ⇒ Integer?
The number of rows patched by the write request.
61 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 61 optional :rows_patched, Integer |
#rows_remaining ⇒ Boolean?
Whether more documents match the filter for partial operations.
67 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 67 optional :rows_remaining, Turbopuffer::Internal::Type::Boolean |
#rows_upserted ⇒ Integer?
The number of rows upserted by the write request.
73 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 73 optional :rows_upserted, Integer |
#status ⇒ Symbol, :OK
The status of the request.
29 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 29 required :status, const: :OK |
#upserted_ids ⇒ Array<String, Integer>?
The IDs of documents that were upserted. Only included when ‘return_affected_ids` is true and at least one document was upserted.
80 |
# File 'lib/turbopuffer/models/namespace_copy_from_response.rb', line 80 optional :upserted_ids, -> { Turbopuffer::Internal::Type::ArrayOf[union: Turbopuffer::ID] } |