Class: Turbopuffer::Models::NamespaceMetadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::NamespaceMetadata
- Defined in:
- lib/turbopuffer/models/namespace_metadata.rb
Overview
Defined Under Namespace
Modules: Index Classes: Pinning
Instance Attribute Summary collapse
-
#approx_logical_bytes ⇒ Integer
The approximate number of logical bytes in the namespace.
-
#approx_row_count ⇒ Integer
The approximate number of rows in the namespace.
-
#created_at ⇒ Time
The timestamp when the namespace was created.
-
#encryption ⇒ Turbopuffer::Models::Encryption::CustomerManaged, Turbopuffer::Models::Encryption::Default
The encryption configuration for a namespace.
- #index ⇒ Turbopuffer::Models::NamespaceMetadata::Index::IndexUpToDate, Turbopuffer::Models::NamespaceMetadata::Index::IndexUpdating
-
#pinning ⇒ Turbopuffer::Models::NamespaceMetadata::Pinning?
Configuration for namespace pinning, along with the current status of the pinned namespace.
-
#schema ⇒ Hash{Symbol=>Turbopuffer::Models::AttributeSchemaConfig}
The schema of the namespace.
-
#updated_at ⇒ Time
The timestamp when the namespace was last modified by a write operation.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(unindexed_bytes:, status: :updating) ⇒ Object
constructor
Some parameter documentations has been truncated, see Index::IndexUpdating for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(unindexed_bytes:, status: :updating) ⇒ Object
Some parameter documentations has been truncated, see Turbopuffer::Models::NamespaceMetadata::Index::IndexUpdating for more details.
|
|
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 55
|
Instance Attribute Details
#approx_logical_bytes ⇒ Integer
The approximate number of logical bytes in the namespace.
11 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 11 required :approx_logical_bytes, Integer |
#approx_row_count ⇒ Integer
The approximate number of rows in the namespace.
17 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 17 required :approx_row_count, Integer |
#created_at ⇒ Time
The timestamp when the namespace was created.
23 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 23 required :created_at, Time |
#encryption ⇒ Turbopuffer::Models::Encryption::CustomerManaged, Turbopuffer::Models::Encryption::Default
The encryption configuration for a namespace.
29 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 29 required :encryption, union: -> { Turbopuffer::Encryption } |
#index ⇒ Turbopuffer::Models::NamespaceMetadata::Index::IndexUpToDate, Turbopuffer::Models::NamespaceMetadata::Index::IndexUpdating
34 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 34 required :index, union: -> { Turbopuffer::NamespaceMetadata::Index } |
#pinning ⇒ Turbopuffer::Models::NamespaceMetadata::Pinning?
Configuration for namespace pinning, along with the current status of the pinned namespace.
53 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 53 optional :pinning, -> { Turbopuffer::NamespaceMetadata::Pinning } |
#schema ⇒ Hash{Symbol=>Turbopuffer::Models::AttributeSchemaConfig}
The schema of the namespace.
40 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 40 required :schema, -> { Turbopuffer::Internal::Type::HashOf[Turbopuffer::AttributeSchemaConfig] } |
#updated_at ⇒ Time
The timestamp when the namespace was last modified by a write operation.
46 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 46 required :updated_at, Time |
Class Method Details
.variants ⇒ Array(Turbopuffer::Models::NamespaceMetadata::Index::IndexUpToDate, Turbopuffer::Models::NamespaceMetadata::Index::IndexUpdating)
|
|
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 117
|