Class: Turbopuffer::Models::NamespaceMetadata::Pinning::Status
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::NamespaceMetadata::Pinning::Status
- Defined in:
- lib/turbopuffer/models/namespace_metadata.rb
Instance Attribute Summary collapse
-
#ready_replicas ⇒ Integer
The number of replicas that are warm and serving traffic.
-
#updated_at ⇒ Time
The timestamp of the latest pinning status snapshot.
-
#utilization ⇒ Float
Aggregate utilization for the pinned namespace, reported as a value between 0.0 and 1.0.
Instance Method Summary collapse
-
#initialize(ready_replicas:, updated_at:, utilization:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Status for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ready_replicas:, updated_at:, utilization:) ⇒ Object
Some parameter documentations has been truncated, see Turbopuffer::Models::NamespaceMetadata::Pinning::Status for more details.
Operational status for a pinned namespace.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 135 class Status < Turbopuffer::Internal::Type::BaseModel # @!attribute ready_replicas # The number of replicas that are warm and serving traffic. # # @return [Integer] required :ready_replicas, Integer # @!attribute updated_at # The timestamp of the latest pinning status snapshot. # # @return [Time] required :updated_at, Time # @!attribute utilization # Aggregate utilization for the pinned namespace, reported as a value between 0.0 # and 1.0. # # @return [Float] required :utilization, Float # @!method initialize(ready_replicas:, updated_at:, utilization:) # Some parameter documentations has been truncated, see # {Turbopuffer::Models::NamespaceMetadata::Pinning::Status} for more details. # # Operational status for a pinned namespace. # # @param ready_replicas [Integer] The number of replicas that are warm and serving traffic. # # @param updated_at [Time] The timestamp of the latest pinning status snapshot. # # @param utilization [Float] Aggregate utilization for the pinned namespace, reported as a value between 0.0 end |
Instance Attribute Details
#ready_replicas ⇒ Integer
The number of replicas that are warm and serving traffic.
140 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 140 required :ready_replicas, Integer |
#updated_at ⇒ Time
The timestamp of the latest pinning status snapshot.
146 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 146 required :updated_at, Time |
#utilization ⇒ Float
Aggregate utilization for the pinned namespace, reported as a value between 0.0 and 1.0.
153 |
# File 'lib/turbopuffer/models/namespace_metadata.rb', line 153 required :utilization, Float |