Class: Turbopuffer::Models::NamespaceRecallResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::NamespaceRecallResponse
- Defined in:
- lib/turbopuffer/models/namespace_recall_response.rb,
sig/turbopuffer/models/namespace_recall_response.rbs
Overview
Defined Under Namespace
Classes: GroundTruth
Instance Attribute Summary collapse
-
#avg_ann_count ⇒ Float
The average number of documents retrieved by the approximate nearest neighbor searches.
-
#avg_exhaustive_count ⇒ Float
The average number of documents retrieved by the exhaustive searches.
-
#avg_recall ⇒ Float
The average recall of the queries.
-
#ground_truth ⇒ Array<Turbopuffer::Models::NamespaceRecallResponse::GroundTruth>?
Ground truth data including query vectors and true nearest neighbors.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
24 |
# File 'sig/turbopuffer/models/namespace_recall_response.rbs', line 24
def initialize: (
|
Instance Attribute Details
#avg_ann_count ⇒ Float
The average number of documents retrieved by the approximate nearest neighbor searches.
12 |
# File 'lib/turbopuffer/models/namespace_recall_response.rb', line 12 required :avg_ann_count, Float |
#avg_exhaustive_count ⇒ Float
The average number of documents retrieved by the exhaustive searches.
18 |
# File 'lib/turbopuffer/models/namespace_recall_response.rb', line 18 required :avg_exhaustive_count, Float |
#avg_recall ⇒ Float
The average recall of the queries.
24 |
# File 'lib/turbopuffer/models/namespace_recall_response.rb', line 24 required :avg_recall, Float |
#ground_truth ⇒ Array<Turbopuffer::Models::NamespaceRecallResponse::GroundTruth>?
Ground truth data including query vectors and true nearest neighbors. Only included when include_ground_truth is true.
31 32 |
# File 'lib/turbopuffer/models/namespace_recall_response.rb', line 31 optional :ground_truth, -> { Turbopuffer::Internal::Type::ArrayOf[Turbopuffer::Models::NamespaceRecallResponse::GroundTruth] } |
Instance Method Details
#to_hash ⇒ {
31 |
# File 'sig/turbopuffer/models/namespace_recall_response.rbs', line 31
def to_hash: -> {
|