Class: Turbopuffer::Models::NamespaceWriteParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Turbopuffer::Models::NamespaceWriteParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/turbopuffer/models/namespace_write_params.rb
Overview
Defined Under Namespace
Classes: Encryption, PatchByFilter
Instance Attribute Summary collapse
-
#copy_from_namespace ⇒ String?
The namespace to copy documents from.
-
#delete_by_filter ⇒ Object?
The filter specifying which documents to delete.
-
#delete_condition ⇒ Object?
A condition evaluated against the current value of each document targeted by a delete write.
- #deletes ⇒ Array<String, Integer>?
-
#disable_backpressure ⇒ Boolean?
Disables write throttling (HTTP 429 responses) during high-volume ingestion.
-
#distance_metric ⇒ Symbol, ...
A function used to calculate vector similarity.
-
#encryption ⇒ Turbopuffer::Models::NamespaceWriteParams::Encryption?
The encryption configuration for a namespace.
- #namespace ⇒ String?
-
#patch_by_filter ⇒ Turbopuffer::Models::NamespaceWriteParams::PatchByFilter?
The patch and filter specifying which documents to patch.
-
#patch_columns ⇒ Turbopuffer::Models::Columns?
A list of documents in columnar format.
-
#patch_condition ⇒ Object?
A condition evaluated against the current value of each document targeted by a patch write.
- #patch_rows ⇒ Array<Turbopuffer::Models::Row>?
-
#schema ⇒ Hash{Symbol=>String, Turbopuffer::Models::AttributeSchemaConfig}?
The schema of the attributes attached to the documents.
-
#upsert_columns ⇒ Turbopuffer::Models::Columns?
A list of documents in columnar format.
-
#upsert_condition ⇒ Object?
A condition evaluated against the current value of each document targeted by an upsert write.
- #upsert_rows ⇒ Array<Turbopuffer::Models::Row>?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(key_name: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Encryption::Cmek for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key_name: ) ⇒ Object
Some parameter documentations has been truncated, see Turbopuffer::Models::NamespaceWriteParams::Encryption::Cmek for more details.
|
|
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 165
|
Instance Attribute Details
#copy_from_namespace ⇒ String?
The namespace to copy documents from.
19 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 19 optional :copy_from_namespace, String |
#delete_by_filter ⇒ Object?
The filter specifying which documents to delete.
25 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 25 optional :delete_by_filter, Turbopuffer::Internal::Type::Unknown |
#delete_condition ⇒ Object?
A condition evaluated against the current value of each document targeted by a delete write. Only documents that pass the condition are deleted.
32 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 32 optional :delete_condition, Turbopuffer::Internal::Type::Unknown |
#deletes ⇒ Array<String, Integer>?
37 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 37 optional :deletes, -> { Turbopuffer::Internal::Type::ArrayOf[union: Turbopuffer::ID] } |
#disable_backpressure ⇒ Boolean?
Disables write throttling (HTTP 429 responses) during high-volume ingestion.
43 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 43 optional :disable_backpressure, Turbopuffer::Internal::Type::Boolean |
#distance_metric ⇒ Symbol, ...
A function used to calculate vector similarity.
49 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 49 optional :distance_metric, enum: -> { Turbopuffer::DistanceMetric } |
#encryption ⇒ Turbopuffer::Models::NamespaceWriteParams::Encryption?
The encryption configuration for a namespace.
55 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 55 optional :encryption, -> { Turbopuffer::NamespaceWriteParams::Encryption } |
#namespace ⇒ String?
13 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 13 optional :namespace, String |
#patch_by_filter ⇒ Turbopuffer::Models::NamespaceWriteParams::PatchByFilter?
The patch and filter specifying which documents to patch.
61 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 61 optional :patch_by_filter, -> { Turbopuffer::NamespaceWriteParams::PatchByFilter } |
#patch_columns ⇒ Turbopuffer::Models::Columns?
A list of documents in columnar format. Each key is a column name, mapped to an array of values for that column.
68 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 68 optional :patch_columns, -> { Turbopuffer::Columns } |
#patch_condition ⇒ Object?
A condition evaluated against the current value of each document targeted by a patch write. Only documents that pass the condition are patched.
75 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 75 optional :patch_condition, Turbopuffer::Internal::Type::Unknown |
#patch_rows ⇒ Array<Turbopuffer::Models::Row>?
80 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 80 optional :patch_rows, -> { Turbopuffer::Internal::Type::ArrayOf[Turbopuffer::Row] } |
#schema ⇒ Hash{Symbol=>String, Turbopuffer::Models::AttributeSchemaConfig}?
The schema of the attributes attached to the documents.
86 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 86 optional :schema, -> { Turbopuffer::Internal::Type::HashOf[union: Turbopuffer::AttributeSchema] } |
#upsert_columns ⇒ Turbopuffer::Models::Columns?
A list of documents in columnar format. Each key is a column name, mapped to an array of values for that column.
93 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 93 optional :upsert_columns, -> { Turbopuffer::Columns } |
#upsert_condition ⇒ Object?
A condition evaluated against the current value of each document targeted by an upsert write. Only documents that pass the condition are upserted.
100 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 100 optional :upsert_condition, Turbopuffer::Internal::Type::Unknown |
#upsert_rows ⇒ Array<Turbopuffer::Models::Row>?
105 |
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 105 optional :upsert_rows, -> { Turbopuffer::Internal::Type::ArrayOf[Turbopuffer::Row] } |