Class: Turbopuffer::Models::NamespaceWriteParams::PatchByFilter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/turbopuffer/models/namespace_write_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filters:, patch:) ⇒ Object

The patch and filter specifying which documents to patch.

Parameters:

  • filters (Object)

    Filter by attributes. Same syntax as the query endpoint.

  • patch (Hash{Symbol=>Object})


179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 179

class PatchByFilter < Turbopuffer::Internal::Type::BaseModel
  # @!attribute filters
  #   Filter by attributes. Same syntax as the query endpoint.
  #
  #   @return [Object]
  required :filters, Turbopuffer::Internal::Type::Unknown

  # @!attribute patch
  #
  #   @return [Hash{Symbol=>Object}]
  required :patch, Turbopuffer::Internal::Type::HashOf[Turbopuffer::Internal::Type::Unknown]

  # @!method initialize(filters:, patch:)
  #   The patch and filter specifying which documents to patch.
  #
  #   @param filters [Object] Filter by attributes. Same syntax as the query endpoint.
  #
  #   @param patch [Hash{Symbol=>Object}]
end

Instance Attribute Details

#filtersObject

Filter by attributes. Same syntax as the query endpoint.

Returns:

  • (Object)


184
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 184

required :filters, Turbopuffer::Internal::Type::Unknown

#patchHash{Symbol=>Object}

Returns:

  • (Hash{Symbol=>Object})


189
# File 'lib/turbopuffer/models/namespace_write_params.rb', line 189

required :patch, Turbopuffer::Internal::Type::HashOf[Turbopuffer::Internal::Type::Unknown]